@@ -1,9 +1,10 @@
 from __future__ import unicode_literals
 
 import os
-import re
+# import re
 import subprocess
 from fnmatch import fnmatch
+from django.utils.translation import ugettext_lazy as _
 
 from log_reader import settings
 
@@ -12,12 +13,15 @@ def get_log_files(directory):
     for (dir_path, dir_names, filenames) in os.walk(directory):
         log_files = []
         all_files = list(filter(lambda x: x.find('~') == -1, filenames))
-        log_files.extend([x for x in all_files if fnmatch(x, settings.LOG_READER_FILES_PATTERN)])
+        log_files.extend([x for x in all_files if fnmatch(x, settings.LOG_READER_FILES_PATTERN) and x not in settings.LOG_READER_EXCLUDE_FILES])
         return list(set(log_files))
     return []
 
 
 def read_file_lines(file_name):
+    if file_name not in get_log_files(settings.LOG_READER_DIR_PATH):
+        return False, _("%s file, not found. Please try again." % file_name)
+
     try:
         file_path = '%s/%s' % (settings.LOG_READER_DIR_PATH, file_name)
         result = subprocess.run(
@@ -34,8 +38,9 @@ def read_file_lines(file_name):
 
 
 def split_file_content(content):
-    res = content.split(settings.LOG_READER_SPLIT_PATTERN) if content else []
+    data = content.split(settings.LOG_READER_SPLIT_PATTERN) if content else []
     # if content and len(res) == 1:
     #     res = re.findall(settings.LOG_READER_REGEX_SPLIT_PATTERN, content) if content else []
+    res = [x for x in data if len(x) > 5]
     return res
 
